/*
 *  linux/arch/mips/kernel/proc.c
 *
 *  Copyright (C) 1995, 1996  Ralf Baechle
 */
#include <linux/delay.h>
#include <linux/kernel.h>
#include <asm/bootinfo.h>
#include <asm/mipsregs.h>

unsigned long dflushes = 0;
unsigned long iflushes = 0;

/*
 * BUFFER is PAGE_SIZE bytes long.
 *
 * Currently /proc/cpuinfo is being abused to print data about the
 * number of date/instruction cacheflushes.
 */
int get_cpuinfo(char *buffer)
{
	const char *cpu_name[] = CPU_NAMES;
	const char *mach_name[] = MACH_NAMES;
	unsigned int version = read_32bit_cp0_register(CP0_PRID);

	return sprintf(buffer,
		       "cpu\t\t\t: MIPS\n"
		       "cpu model\t\t: %s V%d.%d\n"
		       "system type\t\t: %s\n"
		       "BogoMIPS\t\t: %lu.%02lu\n"
		       "D-cacheflushes\t\t: %lu\n"
		       "I-cacheflushes\t\t: %lu\n",

		       cpu_name[mips_cputype <= CPU_LAST ? mips_cputype : CPU_UNKNOWN], (version >> 4) & 0x0f, version & 0x0f,
		       mach_name[mips_machtype <= MACH_LAST ? mips_machtype : MACH_UNKNOWN],
		       loops_per_sec / 500000, (loops_per_sec / 5000) % 100,
		       dflushes,iflushes
		       );
}
