/*
 * Functions depending of the byteorder.
 *
 * This file is subject to the terms and conditions of the GNU General Public
 * License.  See the file "COPYING" in the main directory of this archive
 * for more details.
 *
 * Copyright (C) 1995, 1996 by Ralf Baechle
 */
#ifndef __ASM_MIPS_BYTEORDER_H
#define __ASM_MIPS_BYTEORDER_H

#ifndef __EXTERN_INLINE
#define __EXTERN_INLINE extern __inline__
#endif

__EXTERN_INLINE unsigned long int	ntohl(unsigned long int x);
__EXTERN_INLINE unsigned short int	ntohs(unsigned short int x);
__EXTERN_INLINE unsigned long int	htonl(unsigned long int x);
__EXTERN_INLINE unsigned short int	htons(unsigned short int x);

#if defined (__MIPSEB__)
#define __BIG_ENDIAN
#define __BIG_ENDIAN_BITFIELD

__EXTERN_INLINE unsigned long int	ntohl(unsigned long int x)
{
	return x;
}

__EXTERN_INLINE unsigned short int	ntohs(unsigned short int x)
{
	return x;
}

__EXTERN_INLINE unsigned long int	htonl(unsigned long int x)
{
	return x;
}

__EXTERN_INLINE unsigned short int	htons(unsigned short int x)
{
	return x;
}

#elif defined (__MIPSEL__)
#define __LITTLE_ENDIAN
#define __LITTLE_ENDIAN_BITFIELD

/*
 * No need to optimize this; GCC generates perfect code from this.
 * The old constant macros had anyway the problem that one could take
 * the address of these.
 */

__EXTERN_INLINE unsigned long int
ntohl(unsigned long int x)
{
	return (((x & 0x000000ffU) << 24) |
		((x & 0x0000ff00U) <<  8) |
		((x & 0x00ff0000U) >>  8) |
		((x & 0xff000000U) >> 24));
}

__EXTERN_INLINE unsigned short int
ntohs(unsigned short int x)
{
	return (((x & 0x00ff) << 8) |
		((x & 0xff00) >> 8));
}

__EXTERN_INLINE unsigned long int
htonl(unsigned long int x)
{
	return (((x & 0x000000ffU) << 24) |
		((x & 0x0000ff00U) <<  8) |
		((x & 0x00ff0000U) >>  8) |
		((x & 0xff000000U) >> 24));
}

__EXTERN_INLINE unsigned short int
htons(unsigned short int x)
{
	return (((x & 0x00ff) << 8) |
		((x & 0xff00) >> 8));
}
#else
#error "MIPS but neither __MIPSEL__ nor __MIPSEB__?"
#endif

#endif /* __ASM_MIPS_BYTEORDER_H */
